package com.ruoyi.ss.suitTemp.domain;

import java.math.BigDecimal;

import com.fasterxml.jackson.annotation.JsonView;
import com.ruoyi.common.core.domain.JsonViewProfile;
import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.validRule.suitTempExist.SuitTempExist;
import com.ruoyi.ss.device.domain.DeviceView;
import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * 套餐模板对象 sm_suit_temp
 *
 * @author ruoyi
 * @date 2024-07-15
 */
@Data
public class SuitTemp extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 模板ID */
    @SuitTempExist(message = "模板不存在", checkBelong = true, groups = { ValidGroup.FrontUpdate.class})
    @JsonView(JsonViewProfile.App.class)
    private Long tempId;

    /** 用户ID */
    @Excel(name = "用户ID")
    @NotNull(message = "用户不允许为空", groups = {ValidGroup.Create.class})
    @JsonView(JsonViewProfile.App.class)
    private Long userId;

    /** 套餐名称 */
    @Excel(name = "套餐名称")
    @NotNull(message = "套餐名称不允许为空", groups = {ValidGroup.Create.class, ValidGroup.FrontCreate.class})
    @Size(min = 1, max = 50, message = "套餐名称长度在1~50个字符之间")
    @JsonView(JsonViewProfile.App.class)
    private String name;

    /** 价格(元） */
    @Excel(name = "价格(元）")
    @NotNull(message = "价格不允许为空", groups = {ValidGroup.Create.class, ValidGroup.FrontCreate.class})
    @Min(value = 0, message = "价格不允许小于0")
    @JsonView(JsonViewProfile.App.class)
    private BigDecimal price;

    /** 通电时间（分钟） */
    @Excel(name = "通电时间", readConverterExp = "分=钟")
    @NotNull(message = "通电时间不允许为空", groups = {ValidGroup.Create.class, ValidGroup.FrontCreate.class})
    @Min(value = 1, message = "通电时间不允许小于1分钟")
    @JsonView(JsonViewProfile.App.class)
    private BigDecimal value;

    /** 详细说明 */
    @Excel(name = "详细说明")
    @Size(max = 200, message = "详细说明长度不能超过200个字符")
    @JsonView(JsonViewProfile.App.class)
    private String description;
}
