package com.ruoyi.web.controller.app;

import com.fasterxml.jackson.annotation.JsonView;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.JsonViewProfile;
import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.ss.suitTemp.domain.SuitTempQuery;
import com.ruoyi.ss.suitTemp.domain.SuitTempVO;
import com.ruoyi.ss.suitTemp.service.SuitTempConverter;
import com.ruoyi.ss.suitTemp.service.SuitTempService;
import com.ruoyi.ss.suitTemp.service.SuitTempValidator;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author wjh
 * 2024/7/15
 */
@RestController
@RequestMapping("/app/suit/temp")
public class AppSuitTempController extends BaseController {

    @Autowired
    private SuitTempService suitTempService;

    @Autowired
    private SuitTempValidator suitTempValidator;

    @Autowired
    private SuitTempConverter suitTempConverter;

    @ApiOperation("查询本人套餐模板列表")
    @GetMapping("/list")
    @JsonView(JsonViewProfile.App.class)
    public TableDataInfo list(SuitTempQuery query)
    {
        startPage();
        query.setUserId(getUserId());
        List<SuitTempVO> list = suitTempService.selectSuitTempList(query);
        return getDataTable(list);
    }

    @ApiOperation("获取套餐模板详细信息")
    @GetMapping(value = "/{tempId}")
    @JsonView(JsonViewProfile.App.class)
    public AjaxResult getInfo(@PathVariable("tempId") Long tempId)
    {
        SuitTempVO temp = suitTempService.selectSuitTempByTempId(tempId);
        if (!suitTempValidator.checkBelong(temp, getUserId())) {
            return error("这不是您的套餐模板,无权查看");
        }
        return success(temp);
    }

    @ApiOperation("新增套餐模板")
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.FrontCreate.class) SuitTempVO vo) {
        vo.setUserId(getUserId());
        return toAjax(suitTempService.insertSuitTemp(suitTempConverter.toPoByAppCreate(vo)));
    }

    @ApiOperation("修改套餐模板")
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.FrontUpdate.class) SuitTempVO vo) {
        return toAjax(suitTempService.updateSuitTemp(suitTempConverter.toPoByAppUpdate(vo)));
    }

    @ApiOperation("删除套餐模板")
    @DeleteMapping("/{tempId}")
    public AjaxResult remove(@PathVariable Long tempId) {
        if (!suitTempValidator.checkBelong(tempId, getUserId())) {
            return error("这不是您的套餐模板,无权删除");
        }
        return toAjax(suitTempService.deleteSuitTempByTempId(tempId));
    }

}
