package com.ruoyi.web.controller.ss;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.ss.suitTemp.domain.SuitTempQuery;
import com.ruoyi.ss.suitTemp.domain.SuitTempVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.suitTemp.domain.SuitTemp;
import com.ruoyi.ss.suitTemp.service.SuitTempService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 套餐模板Controller
 *
 * @author ruoyi
 * @date 2024-07-15
 */
@RestController
@RequestMapping("/ss/suitTemp")
public class SuitTempController extends BaseController
{
    @Autowired
    private SuitTempService suitTempService;

    /**
     * 查询套餐模板列表
     */
    @PreAuthorize("@ss.hasPermi('ss:suitTemp:list')")
    @GetMapping("/list")
    public TableDataInfo list(SuitTempQuery suitTemp)
    {
        startPage();
        List<SuitTempVO> list = suitTempService.selectSuitTempList(suitTemp);
        return getDataTable(list);
    }

    /**
     * 导出套餐模板列表
     */
    @PreAuthorize("@ss.hasPermi('ss:suitTemp:export')")
    @Log(title = "套餐模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SuitTempQuery suitTemp)
    {
        List<SuitTempVO> list = suitTempService.selectSuitTempList(suitTemp);
        ExcelUtil<SuitTempVO> util = new ExcelUtil<SuitTempVO>(SuitTempVO.class);
        util.exportExcel(response, list, "套餐模板数据");
    }

    /**
     * 获取套餐模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('ss:suitTemp:query')")
    @GetMapping(value = "/{tempId}")
    public AjaxResult getInfo(@PathVariable("tempId") Long tempId)
    {
        return success(suitTempService.selectSuitTempByTempId(tempId));
    }

    /**
     * 新增套餐模板
     */
    @PreAuthorize("@ss.hasPermi('ss:suitTemp:add')")
    @Log(title = "套餐模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SuitTemp suitTemp)
    {
        return toAjax(suitTempService.insertSuitTemp(suitTemp));
    }

    /**
     * 修改套餐模板
     */
    @PreAuthorize("@ss.hasPermi('ss:suitTemp:edit')")
    @Log(title = "套餐模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SuitTemp suitTemp)
    {
        return toAjax(suitTempService.updateSuitTemp(suitTemp));
    }

    /**
     * 删除套餐模板
     */
    @PreAuthorize("@ss.hasPermi('ss:suitTemp:remove')")
    @Log(title = "套餐模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{tempIds}")
    public AjaxResult remove(@PathVariable Long[] tempIds)
    {
        return toAjax(suitTempService.deleteSuitTempByTempIds(tempIds));
    }
}
